# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: config_msgs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import common_msgs_pb2 as common__msgs__pb2
import device_msgs_pb2 as device__msgs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='config_msgs.proto',
  package='Nrmk.IndyFramework',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x11\x63onfig_msgs.proto\x12\x12Nrmk.IndyFramework\x1a\x11\x63ommon_msgs.proto\x1a\x11\x64\x65vice_msgs.proto\"\x15\n\x05\x46rame\x12\x0c\n\x04\x66pos\x18\x01 \x03(\x02\"6\n\rFTsensorFrame\x12\x13\n\x0btranslation\x18\x01 \x01(\x02\x12\x10\n\x08rotation\x18\x02 \x01(\x02\"\x18\n\x08JointPos\x12\x0c\n\x04jpos\x18\x01 \x03(\x02\":\n\x0bPlanarFrame\x12\r\n\x05\x66pos0\x18\x01 \x03(\x02\x12\r\n\x05\x66pos1\x18\x02 \x03(\x02\x12\r\n\x05\x66pos2\x18\x03 \x03(\x02\"K\n\x0b\x46rameResult\x12\x0c\n\x04\x66pos\x18\x01 \x03(\x02\x12.\n\x08response\x18\x02 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.Response\"\x16\n\x05Ratio\x12\r\n\x05ratio\x18\x01 \x01(\r\"2\n\x12\x41utoServoOffConfig\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08\x12\x0c\n\x04time\x18\x02 \x01(\x02\"\xc4\x02\n\x10\x43ollTuningConfig\x12G\n\tprecision\x18\x01 \x01(\x0e\x32\x34.Nrmk.IndyFramework.CollTuningConfig.TuningPrecision\x12\x46\n\x0ctuning_space\x18\x02 \x01(\x0e\x32\x30.Nrmk.IndyFramework.CollTuningConfig.TuningSpace\x12\x15\n\rvel_level_max\x18\x03 \x01(\x05\"?\n\x0fTuningPrecision\x12\x0c\n\x08LOW_TUNE\x10\x00\x12\x0f\n\x0bMIDDLE_TUNE\x10\x01\x12\r\n\tHIGH_TUNE\x10\x02\"G\n\x0bTuningSpace\x12\x0b\n\x07NO_TUNE\x10\x00\x12\x0e\n\nJOINT_TUNE\x10\x01\x12\r\n\tTASK_TUNE\x10\x02\x12\x0c\n\x08\x41LL_TUNE\x10\x03\"3\n\x0cJointGainSet\x12\n\n\x02kp\x18\x01 \x03(\x02\x12\n\n\x02kv\x18\x02 \x03(\x02\x12\x0b\n\x03kl2\x18\x03 \x03(\x02\"2\n\x0bTaskGainSet\x12\n\n\x02kp\x18\x01 \x03(\x02\x12\n\n\x02kv\x18\x02 \x03(\x02\x12\x0b\n\x03kl2\x18\x03 \x03(\x02\"Q\n\x10ImpedanceGainSet\x12\x0c\n\x04mass\x18\x01 \x03(\x02\x12\x0f\n\x07\x64\x61mping\x18\x02 \x03(\x02\x12\x11\n\tstiffness\x18\x03 \x03(\x02\x12\x0b\n\x03kl2\x18\x04 \x03(\x02\"\x7f\n\x0c\x46orceGainSet\x12\n\n\x02kp\x18\x01 \x03(\x02\x12\n\n\x02kv\x18\x02 \x03(\x02\x12\x0b\n\x03kl2\x18\x03 \x03(\x02\x12\x0c\n\x04mass\x18\x04 \x03(\x02\x12\x0f\n\x07\x64\x61mping\x18\x05 \x03(\x02\x12\x11\n\tstiffness\x18\x06 \x03(\x02\x12\x0b\n\x03kpf\x18\x07 \x03(\x02\x12\x0b\n\x03kif\x18\x08 \x03(\x02\"i\n\x0bTestGainSet\x12\r\n\x05kpctc\x18\x01 \x03(\x02\x12\r\n\x05kvctc\x18\x02 \x03(\x02\x12\r\n\x05kictc\x18\x03 \x03(\x02\x12\r\n\x05knric\x18\x04 \x03(\x02\x12\x0e\n\x06kpnric\x18\x05 \x03(\x02\x12\x0e\n\x06kinric\x18\x06 \x03(\x02\"\xa5\x01\n\rCustomGainSet\x12\r\n\x05gain0\x18\x01 \x03(\x02\x12\r\n\x05gain1\x18\x02 \x03(\x02\x12\r\n\x05gain2\x18\x03 \x03(\x02\x12\r\n\x05gain3\x18\x04 \x03(\x02\x12\r\n\x05gain4\x18\x05 \x03(\x02\x12\r\n\x05gain5\x18\x06 \x03(\x02\x12\r\n\x05gain6\x18\x07 \x03(\x02\x12\r\n\x05gain7\x18\x08 \x03(\x02\x12\r\n\x05gain8\x18\t \x03(\x02\x12\r\n\x05gain9\x18\n \x03(\x02\":\n\x16NewControllerTestState\x12\x0f\n\x07Jenable\x18\x01 \x01(\x08\x12\x0f\n\x07Tenable\x18\x02 \x01(\x08\"\x87\x01\n\x0f\x46rictionCompSet\x12\x1b\n\x13\x63ontrol_comp_enable\x18\x01 \x01(\x08\x12\x1b\n\x13\x63ontrol_comp_levels\x18\x02 \x03(\x05\x12\x1c\n\x14teaching_comp_enable\x18\x03 \x01(\x08\x12\x1c\n\x14teaching_comp_levels\x18\x04 \x03(\x05\"(\n\x0eMountingAngles\x12\n\n\x02ry\x18\x01 \x01(\x02\x12\n\n\x02rz\x18\x02 \x01(\x02\"G\n\x0eToolProperties\x12\x0c\n\x04mass\x18\x01 \x01(\x02\x12\x16\n\x0e\x63\x65nter_of_mass\x18\x02 \x03(\x02\x12\x0f\n\x07inertia\x18\x03 \x03(\x02\"#\n\x12\x43ollisionSensLevel\x12\r\n\x05level\x18\x01 \x01(\r\"\xb2\x02\n\x13\x43ollisionThresholds\x12\x16\n\x0ej_torque_bases\x18\x01 \x03(\x02\x12\x19\n\x11j_torque_tangents\x18\x02 \x03(\x02\x12\x16\n\x0et_torque_bases\x18\x03 \x03(\x02\x12\x19\n\x11t_torque_tangents\x18\x04 \x03(\x02\x12\x13\n\x0b\x65rror_bases\x18\x05 \x03(\x02\x12\x16\n\x0e\x65rror_tangents\x18\x06 \x03(\x02\x12\x1f\n\x17t_constvel_torque_bases\x18\x07 \x03(\x02\x12\"\n\x1at_constvel_torque_tangents\x18\x08 \x03(\x02\x12\x1f\n\x17t_conveyor_torque_bases\x18\t \x03(\x02\x12\"\n\x1at_conveyor_torque_tangents\x18\n \x03(\x02\"t\n\x0f\x43ollisionPolicy\x12\x37\n\x06policy\x18\x01 \x01(\x0e\x32\'.Nrmk.IndyFramework.CollisionPolicyType\x12\x12\n\nsleep_time\x18\x02 \x01(\x02\x12\x14\n\x0cgravity_time\x18\x03 \x01(\x02\"\xc4\x01\n\x0cSafetyLimits\x12\x13\n\x0bpower_limit\x18\x01 \x01(\x02\x12\x19\n\x11power_limit_ratio\x18\x02 \x01(\x02\x12\x17\n\x0ftcp_force_limit\x18\x03 \x01(\x02\x12\x1d\n\x15tcp_force_limit_ratio\x18\x04 \x01(\x02\x12\x17\n\x0ftcp_speed_limit\x18\x05 \x01(\x02\x12\x1d\n\x15tcp_speed_limit_ratio\x18\x06 \x01(\x02\x12\x14\n\x0cjoint_limits\x18\x07 \x03(\x02\"\xb0\x03\n\x10SafetyStopConfig\x12G\n\x1djoint_position_limit_stop_cat\x18\x01 \x01(\x0e\x32 .Nrmk.IndyFramework.StopCategory\x12\x44\n\x1ajoint_speed_limit_stop_cat\x18\x02 \x01(\x0e\x32 .Nrmk.IndyFramework.StopCategory\x12\x45\n\x1bjoint_torque_limit_stop_cat\x18\x03 \x01(\x0e\x32 .Nrmk.IndyFramework.StopCategory\x12\x42\n\x18tcp_speed_limit_stop_cat\x18\x04 \x01(\x0e\x32 .Nrmk.IndyFramework.StopCategory\x12\x42\n\x18tcp_force_limit_stop_cat\x18\x05 \x01(\x0e\x32 .Nrmk.IndyFramework.StopCategory\x12>\n\x14power_limit_stop_cat\x18\x06 \x01(\x0e\x32 .Nrmk.IndyFramework.StopCategory\"\xe9\x01\n\x08\x44IConfig\x12\x15\n\rfunction_code\x18\x01 \x01(\x05\x12\x15\n\rfunction_name\x18\x02 \x01(\t\x12\x39\n\x0etriggerSignals\x18\x03 \x03(\x0b\x32!.Nrmk.IndyFramework.DigitalSignal\x12\x39\n\x0esuccessSignals\x18\x04 \x03(\x0b\x32!.Nrmk.IndyFramework.DigitalSignal\x12\x39\n\x0e\x66\x61ilureSignals\x18\x05 \x03(\x0b\x32!.Nrmk.IndyFramework.DigitalSignal\"@\n\x0c\x44IConfigList\x12\x30\n\ndi_configs\x18\x01 \x03(\x0b\x32\x1c.Nrmk.IndyFramework.DIConfig\"\x9f\x01\n\x08\x44OConfig\x12\x12\n\nstate_code\x18\x01 \x01(\x05\x12\x12\n\nstate_name\x18\x02 \x01(\t\x12\x34\n\tonSignals\x18\x03 \x03(\x0b\x32!.Nrmk.IndyFramework.DigitalSignal\x12\x35\n\noffSignals\x18\x04 \x03(\x0b\x32!.Nrmk.IndyFramework.DigitalSignal\"@\n\x0c\x44OConfigList\x12\x30\n\ndo_configs\x18\x01 \x03(\x0b\x32\x1c.Nrmk.IndyFramework.DOConfigb\x06proto3'
  ,
  dependencies=[common__msgs__pb2.DESCRIPTOR,device__msgs__pb2.DESCRIPTOR,])



_COLLTUNINGCONFIG_TUNINGPRECISION = _descriptor.EnumDescriptor(
  name='TuningPrecision',
  full_name='Nrmk.IndyFramework.CollTuningConfig.TuningPrecision',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LOW_TUNE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIDDLE_TUNE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGH_TUNE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=586,
  serialized_end=649,
)
_sym_db.RegisterEnumDescriptor(_COLLTUNINGCONFIG_TUNINGPRECISION)

_COLLTUNINGCONFIG_TUNINGSPACE = _descriptor.EnumDescriptor(
  name='TuningSpace',
  full_name='Nrmk.IndyFramework.CollTuningConfig.TuningSpace',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_TUNE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JOINT_TUNE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TASK_TUNE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALL_TUNE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=651,
  serialized_end=722,
)
_sym_db.RegisterEnumDescriptor(_COLLTUNINGCONFIG_TUNINGSPACE)


_FRAME = _descriptor.Descriptor(
  name='Frame',
  full_name='Nrmk.IndyFramework.Frame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fpos', full_name='Nrmk.IndyFramework.Frame.fpos', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=100,
)


_FTSENSORFRAME = _descriptor.Descriptor(
  name='FTsensorFrame',
  full_name='Nrmk.IndyFramework.FTsensorFrame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='translation', full_name='Nrmk.IndyFramework.FTsensorFrame.translation', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rotation', full_name='Nrmk.IndyFramework.FTsensorFrame.rotation', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=102,
  serialized_end=156,
)


_JOINTPOS = _descriptor.Descriptor(
  name='JointPos',
  full_name='Nrmk.IndyFramework.JointPos',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jpos', full_name='Nrmk.IndyFramework.JointPos.jpos', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=158,
  serialized_end=182,
)


_PLANARFRAME = _descriptor.Descriptor(
  name='PlanarFrame',
  full_name='Nrmk.IndyFramework.PlanarFrame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fpos0', full_name='Nrmk.IndyFramework.PlanarFrame.fpos0', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fpos1', full_name='Nrmk.IndyFramework.PlanarFrame.fpos1', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fpos2', full_name='Nrmk.IndyFramework.PlanarFrame.fpos2', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=184,
  serialized_end=242,
)


_FRAMERESULT = _descriptor.Descriptor(
  name='FrameResult',
  full_name='Nrmk.IndyFramework.FrameResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fpos', full_name='Nrmk.IndyFramework.FrameResult.fpos', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='Nrmk.IndyFramework.FrameResult.response', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=244,
  serialized_end=319,
)


_RATIO = _descriptor.Descriptor(
  name='Ratio',
  full_name='Nrmk.IndyFramework.Ratio',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ratio', full_name='Nrmk.IndyFramework.Ratio.ratio', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=321,
  serialized_end=343,
)


_AUTOSERVOOFFCONFIG = _descriptor.Descriptor(
  name='AutoServoOffConfig',
  full_name='Nrmk.IndyFramework.AutoServoOffConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enable', full_name='Nrmk.IndyFramework.AutoServoOffConfig.enable', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='Nrmk.IndyFramework.AutoServoOffConfig.time', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=345,
  serialized_end=395,
)


_COLLTUNINGCONFIG = _descriptor.Descriptor(
  name='CollTuningConfig',
  full_name='Nrmk.IndyFramework.CollTuningConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='precision', full_name='Nrmk.IndyFramework.CollTuningConfig.precision', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tuning_space', full_name='Nrmk.IndyFramework.CollTuningConfig.tuning_space', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vel_level_max', full_name='Nrmk.IndyFramework.CollTuningConfig.vel_level_max', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _COLLTUNINGCONFIG_TUNINGPRECISION,
    _COLLTUNINGCONFIG_TUNINGSPACE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=398,
  serialized_end=722,
)


_JOINTGAINSET = _descriptor.Descriptor(
  name='JointGainSet',
  full_name='Nrmk.IndyFramework.JointGainSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kp', full_name='Nrmk.IndyFramework.JointGainSet.kp', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kv', full_name='Nrmk.IndyFramework.JointGainSet.kv', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kl2', full_name='Nrmk.IndyFramework.JointGainSet.kl2', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=724,
  serialized_end=775,
)


_TASKGAINSET = _descriptor.Descriptor(
  name='TaskGainSet',
  full_name='Nrmk.IndyFramework.TaskGainSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kp', full_name='Nrmk.IndyFramework.TaskGainSet.kp', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kv', full_name='Nrmk.IndyFramework.TaskGainSet.kv', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kl2', full_name='Nrmk.IndyFramework.TaskGainSet.kl2', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=777,
  serialized_end=827,
)


_IMPEDANCEGAINSET = _descriptor.Descriptor(
  name='ImpedanceGainSet',
  full_name='Nrmk.IndyFramework.ImpedanceGainSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mass', full_name='Nrmk.IndyFramework.ImpedanceGainSet.mass', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='damping', full_name='Nrmk.IndyFramework.ImpedanceGainSet.damping', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stiffness', full_name='Nrmk.IndyFramework.ImpedanceGainSet.stiffness', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kl2', full_name='Nrmk.IndyFramework.ImpedanceGainSet.kl2', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=829,
  serialized_end=910,
)


_FORCEGAINSET = _descriptor.Descriptor(
  name='ForceGainSet',
  full_name='Nrmk.IndyFramework.ForceGainSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kp', full_name='Nrmk.IndyFramework.ForceGainSet.kp', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kv', full_name='Nrmk.IndyFramework.ForceGainSet.kv', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kl2', full_name='Nrmk.IndyFramework.ForceGainSet.kl2', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mass', full_name='Nrmk.IndyFramework.ForceGainSet.mass', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='damping', full_name='Nrmk.IndyFramework.ForceGainSet.damping', index=4,
      number=5, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stiffness', full_name='Nrmk.IndyFramework.ForceGainSet.stiffness', index=5,
      number=6, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kpf', full_name='Nrmk.IndyFramework.ForceGainSet.kpf', index=6,
      number=7, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kif', full_name='Nrmk.IndyFramework.ForceGainSet.kif', index=7,
      number=8, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=912,
  serialized_end=1039,
)


_TESTGAINSET = _descriptor.Descriptor(
  name='TestGainSet',
  full_name='Nrmk.IndyFramework.TestGainSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kpctc', full_name='Nrmk.IndyFramework.TestGainSet.kpctc', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kvctc', full_name='Nrmk.IndyFramework.TestGainSet.kvctc', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kictc', full_name='Nrmk.IndyFramework.TestGainSet.kictc', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='knric', full_name='Nrmk.IndyFramework.TestGainSet.knric', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kpnric', full_name='Nrmk.IndyFramework.TestGainSet.kpnric', index=4,
      number=5, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kinric', full_name='Nrmk.IndyFramework.TestGainSet.kinric', index=5,
      number=6, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1041,
  serialized_end=1146,
)


_CUSTOMGAINSET = _descriptor.Descriptor(
  name='CustomGainSet',
  full_name='Nrmk.IndyFramework.CustomGainSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gain0', full_name='Nrmk.IndyFramework.CustomGainSet.gain0', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gain1', full_name='Nrmk.IndyFramework.CustomGainSet.gain1', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gain2', full_name='Nrmk.IndyFramework.CustomGainSet.gain2', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gain3', full_name='Nrmk.IndyFramework.CustomGainSet.gain3', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gain4', full_name='Nrmk.IndyFramework.CustomGainSet.gain4', index=4,
      number=5, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gain5', full_name='Nrmk.IndyFramework.CustomGainSet.gain5', index=5,
      number=6, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gain6', full_name='Nrmk.IndyFramework.CustomGainSet.gain6', index=6,
      number=7, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gain7', full_name='Nrmk.IndyFramework.CustomGainSet.gain7', index=7,
      number=8, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gain8', full_name='Nrmk.IndyFramework.CustomGainSet.gain8', index=8,
      number=9, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gain9', full_name='Nrmk.IndyFramework.CustomGainSet.gain9', index=9,
      number=10, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1149,
  serialized_end=1314,
)


_NEWCONTROLLERTESTSTATE = _descriptor.Descriptor(
  name='NewControllerTestState',
  full_name='Nrmk.IndyFramework.NewControllerTestState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Jenable', full_name='Nrmk.IndyFramework.NewControllerTestState.Jenable', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Tenable', full_name='Nrmk.IndyFramework.NewControllerTestState.Tenable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1316,
  serialized_end=1374,
)


_FRICTIONCOMPSET = _descriptor.Descriptor(
  name='FrictionCompSet',
  full_name='Nrmk.IndyFramework.FrictionCompSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='control_comp_enable', full_name='Nrmk.IndyFramework.FrictionCompSet.control_comp_enable', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='control_comp_levels', full_name='Nrmk.IndyFramework.FrictionCompSet.control_comp_levels', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='teaching_comp_enable', full_name='Nrmk.IndyFramework.FrictionCompSet.teaching_comp_enable', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='teaching_comp_levels', full_name='Nrmk.IndyFramework.FrictionCompSet.teaching_comp_levels', index=3,
      number=4, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1377,
  serialized_end=1512,
)


_MOUNTINGANGLES = _descriptor.Descriptor(
  name='MountingAngles',
  full_name='Nrmk.IndyFramework.MountingAngles',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ry', full_name='Nrmk.IndyFramework.MountingAngles.ry', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rz', full_name='Nrmk.IndyFramework.MountingAngles.rz', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1514,
  serialized_end=1554,
)


_TOOLPROPERTIES = _descriptor.Descriptor(
  name='ToolProperties',
  full_name='Nrmk.IndyFramework.ToolProperties',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mass', full_name='Nrmk.IndyFramework.ToolProperties.mass', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='center_of_mass', full_name='Nrmk.IndyFramework.ToolProperties.center_of_mass', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inertia', full_name='Nrmk.IndyFramework.ToolProperties.inertia', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1556,
  serialized_end=1627,
)


_COLLISIONSENSLEVEL = _descriptor.Descriptor(
  name='CollisionSensLevel',
  full_name='Nrmk.IndyFramework.CollisionSensLevel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='level', full_name='Nrmk.IndyFramework.CollisionSensLevel.level', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1629,
  serialized_end=1664,
)


_COLLISIONTHRESHOLDS = _descriptor.Descriptor(
  name='CollisionThresholds',
  full_name='Nrmk.IndyFramework.CollisionThresholds',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='j_torque_bases', full_name='Nrmk.IndyFramework.CollisionThresholds.j_torque_bases', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='j_torque_tangents', full_name='Nrmk.IndyFramework.CollisionThresholds.j_torque_tangents', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='t_torque_bases', full_name='Nrmk.IndyFramework.CollisionThresholds.t_torque_bases', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='t_torque_tangents', full_name='Nrmk.IndyFramework.CollisionThresholds.t_torque_tangents', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_bases', full_name='Nrmk.IndyFramework.CollisionThresholds.error_bases', index=4,
      number=5, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_tangents', full_name='Nrmk.IndyFramework.CollisionThresholds.error_tangents', index=5,
      number=6, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='t_constvel_torque_bases', full_name='Nrmk.IndyFramework.CollisionThresholds.t_constvel_torque_bases', index=6,
      number=7, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='t_constvel_torque_tangents', full_name='Nrmk.IndyFramework.CollisionThresholds.t_constvel_torque_tangents', index=7,
      number=8, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='t_conveyor_torque_bases', full_name='Nrmk.IndyFramework.CollisionThresholds.t_conveyor_torque_bases', index=8,
      number=9, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='t_conveyor_torque_tangents', full_name='Nrmk.IndyFramework.CollisionThresholds.t_conveyor_torque_tangents', index=9,
      number=10, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1667,
  serialized_end=1973,
)


_COLLISIONPOLICY = _descriptor.Descriptor(
  name='CollisionPolicy',
  full_name='Nrmk.IndyFramework.CollisionPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='policy', full_name='Nrmk.IndyFramework.CollisionPolicy.policy', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sleep_time', full_name='Nrmk.IndyFramework.CollisionPolicy.sleep_time', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gravity_time', full_name='Nrmk.IndyFramework.CollisionPolicy.gravity_time', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1975,
  serialized_end=2091,
)


_SAFETYLIMITS = _descriptor.Descriptor(
  name='SafetyLimits',
  full_name='Nrmk.IndyFramework.SafetyLimits',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='power_limit', full_name='Nrmk.IndyFramework.SafetyLimits.power_limit', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='power_limit_ratio', full_name='Nrmk.IndyFramework.SafetyLimits.power_limit_ratio', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tcp_force_limit', full_name='Nrmk.IndyFramework.SafetyLimits.tcp_force_limit', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tcp_force_limit_ratio', full_name='Nrmk.IndyFramework.SafetyLimits.tcp_force_limit_ratio', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tcp_speed_limit', full_name='Nrmk.IndyFramework.SafetyLimits.tcp_speed_limit', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tcp_speed_limit_ratio', full_name='Nrmk.IndyFramework.SafetyLimits.tcp_speed_limit_ratio', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='joint_limits', full_name='Nrmk.IndyFramework.SafetyLimits.joint_limits', index=6,
      number=7, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2094,
  serialized_end=2290,
)


_SAFETYSTOPCONFIG = _descriptor.Descriptor(
  name='SafetyStopConfig',
  full_name='Nrmk.IndyFramework.SafetyStopConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='joint_position_limit_stop_cat', full_name='Nrmk.IndyFramework.SafetyStopConfig.joint_position_limit_stop_cat', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='joint_speed_limit_stop_cat', full_name='Nrmk.IndyFramework.SafetyStopConfig.joint_speed_limit_stop_cat', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='joint_torque_limit_stop_cat', full_name='Nrmk.IndyFramework.SafetyStopConfig.joint_torque_limit_stop_cat', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tcp_speed_limit_stop_cat', full_name='Nrmk.IndyFramework.SafetyStopConfig.tcp_speed_limit_stop_cat', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tcp_force_limit_stop_cat', full_name='Nrmk.IndyFramework.SafetyStopConfig.tcp_force_limit_stop_cat', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='power_limit_stop_cat', full_name='Nrmk.IndyFramework.SafetyStopConfig.power_limit_stop_cat', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2293,
  serialized_end=2725,
)


_DICONFIG = _descriptor.Descriptor(
  name='DIConfig',
  full_name='Nrmk.IndyFramework.DIConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='function_code', full_name='Nrmk.IndyFramework.DIConfig.function_code', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='function_name', full_name='Nrmk.IndyFramework.DIConfig.function_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='triggerSignals', full_name='Nrmk.IndyFramework.DIConfig.triggerSignals', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='successSignals', full_name='Nrmk.IndyFramework.DIConfig.successSignals', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failureSignals', full_name='Nrmk.IndyFramework.DIConfig.failureSignals', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2728,
  serialized_end=2961,
)


_DICONFIGLIST = _descriptor.Descriptor(
  name='DIConfigList',
  full_name='Nrmk.IndyFramework.DIConfigList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='di_configs', full_name='Nrmk.IndyFramework.DIConfigList.di_configs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2963,
  serialized_end=3027,
)


_DOCONFIG = _descriptor.Descriptor(
  name='DOConfig',
  full_name='Nrmk.IndyFramework.DOConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state_code', full_name='Nrmk.IndyFramework.DOConfig.state_code', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state_name', full_name='Nrmk.IndyFramework.DOConfig.state_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onSignals', full_name='Nrmk.IndyFramework.DOConfig.onSignals', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offSignals', full_name='Nrmk.IndyFramework.DOConfig.offSignals', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3030,
  serialized_end=3189,
)


_DOCONFIGLIST = _descriptor.Descriptor(
  name='DOConfigList',
  full_name='Nrmk.IndyFramework.DOConfigList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='do_configs', full_name='Nrmk.IndyFramework.DOConfigList.do_configs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3191,
  serialized_end=3255,
)

_FRAMERESULT.fields_by_name['response'].message_type = common__msgs__pb2._RESPONSE
_COLLTUNINGCONFIG.fields_by_name['precision'].enum_type = _COLLTUNINGCONFIG_TUNINGPRECISION
_COLLTUNINGCONFIG.fields_by_name['tuning_space'].enum_type = _COLLTUNINGCONFIG_TUNINGSPACE
_COLLTUNINGCONFIG_TUNINGPRECISION.containing_type = _COLLTUNINGCONFIG
_COLLTUNINGCONFIG_TUNINGSPACE.containing_type = _COLLTUNINGCONFIG
_COLLISIONPOLICY.fields_by_name['policy'].enum_type = common__msgs__pb2._COLLISIONPOLICYTYPE
_SAFETYSTOPCONFIG.fields_by_name['joint_position_limit_stop_cat'].enum_type = common__msgs__pb2._STOPCATEGORY
_SAFETYSTOPCONFIG.fields_by_name['joint_speed_limit_stop_cat'].enum_type = common__msgs__pb2._STOPCATEGORY
_SAFETYSTOPCONFIG.fields_by_name['joint_torque_limit_stop_cat'].enum_type = common__msgs__pb2._STOPCATEGORY
_SAFETYSTOPCONFIG.fields_by_name['tcp_speed_limit_stop_cat'].enum_type = common__msgs__pb2._STOPCATEGORY
_SAFETYSTOPCONFIG.fields_by_name['tcp_force_limit_stop_cat'].enum_type = common__msgs__pb2._STOPCATEGORY
_SAFETYSTOPCONFIG.fields_by_name['power_limit_stop_cat'].enum_type = common__msgs__pb2._STOPCATEGORY
_DICONFIG.fields_by_name['triggerSignals'].message_type = device__msgs__pb2._DIGITALSIGNAL
_DICONFIG.fields_by_name['successSignals'].message_type = device__msgs__pb2._DIGITALSIGNAL
_DICONFIG.fields_by_name['failureSignals'].message_type = device__msgs__pb2._DIGITALSIGNAL
_DICONFIGLIST.fields_by_name['di_configs'].message_type = _DICONFIG
_DOCONFIG.fields_by_name['onSignals'].message_type = device__msgs__pb2._DIGITALSIGNAL
_DOCONFIG.fields_by_name['offSignals'].message_type = device__msgs__pb2._DIGITALSIGNAL
_DOCONFIGLIST.fields_by_name['do_configs'].message_type = _DOCONFIG
DESCRIPTOR.message_types_by_name['Frame'] = _FRAME
DESCRIPTOR.message_types_by_name['FTsensorFrame'] = _FTSENSORFRAME
DESCRIPTOR.message_types_by_name['JointPos'] = _JOINTPOS
DESCRIPTOR.message_types_by_name['PlanarFrame'] = _PLANARFRAME
DESCRIPTOR.message_types_by_name['FrameResult'] = _FRAMERESULT
DESCRIPTOR.message_types_by_name['Ratio'] = _RATIO
DESCRIPTOR.message_types_by_name['AutoServoOffConfig'] = _AUTOSERVOOFFCONFIG
DESCRIPTOR.message_types_by_name['CollTuningConfig'] = _COLLTUNINGCONFIG
DESCRIPTOR.message_types_by_name['JointGainSet'] = _JOINTGAINSET
DESCRIPTOR.message_types_by_name['TaskGainSet'] = _TASKGAINSET
DESCRIPTOR.message_types_by_name['ImpedanceGainSet'] = _IMPEDANCEGAINSET
DESCRIPTOR.message_types_by_name['ForceGainSet'] = _FORCEGAINSET
DESCRIPTOR.message_types_by_name['TestGainSet'] = _TESTGAINSET
DESCRIPTOR.message_types_by_name['CustomGainSet'] = _CUSTOMGAINSET
DESCRIPTOR.message_types_by_name['NewControllerTestState'] = _NEWCONTROLLERTESTSTATE
DESCRIPTOR.message_types_by_name['FrictionCompSet'] = _FRICTIONCOMPSET
DESCRIPTOR.message_types_by_name['MountingAngles'] = _MOUNTINGANGLES
DESCRIPTOR.message_types_by_name['ToolProperties'] = _TOOLPROPERTIES
DESCRIPTOR.message_types_by_name['CollisionSensLevel'] = _COLLISIONSENSLEVEL
DESCRIPTOR.message_types_by_name['CollisionThresholds'] = _COLLISIONTHRESHOLDS
DESCRIPTOR.message_types_by_name['CollisionPolicy'] = _COLLISIONPOLICY
DESCRIPTOR.message_types_by_name['SafetyLimits'] = _SAFETYLIMITS
DESCRIPTOR.message_types_by_name['SafetyStopConfig'] = _SAFETYSTOPCONFIG
DESCRIPTOR.message_types_by_name['DIConfig'] = _DICONFIG
DESCRIPTOR.message_types_by_name['DIConfigList'] = _DICONFIGLIST
DESCRIPTOR.message_types_by_name['DOConfig'] = _DOCONFIG
DESCRIPTOR.message_types_by_name['DOConfigList'] = _DOCONFIGLIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Frame = _reflection.GeneratedProtocolMessageType('Frame', (_message.Message,), {
  'DESCRIPTOR' : _FRAME,
  '__module__' : 'config_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.Frame)
  })
_sym_db.RegisterMessage(Frame)

FTsensorFrame = _reflection.GeneratedProtocolMessageType('FTsensorFrame', (_message.Message,), {
  'DESCRIPTOR' : _FTSENSORFRAME,
  '__module__' : 'config_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.FTsensorFrame)
  })
_sym_db.RegisterMessage(FTsensorFrame)

JointPos = _reflection.GeneratedProtocolMessageType('JointPos', (_message.Message,), {
  'DESCRIPTOR' : _JOINTPOS,
  '__module__' : 'config_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.JointPos)
  })
_sym_db.RegisterMessage(JointPos)

PlanarFrame = _reflection.GeneratedProtocolMessageType('PlanarFrame', (_message.Message,), {
  'DESCRIPTOR' : _PLANARFRAME,
  '__module__' : 'config_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.PlanarFrame)
  })
_sym_db.RegisterMessage(PlanarFrame)

FrameResult = _reflection.GeneratedProtocolMessageType('FrameResult', (_message.Message,), {
  'DESCRIPTOR' : _FRAMERESULT,
  '__module__' : 'config_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.FrameResult)
  })
_sym_db.RegisterMessage(FrameResult)

Ratio = _reflection.GeneratedProtocolMessageType('Ratio', (_message.Message,), {
  'DESCRIPTOR' : _RATIO,
  '__module__' : 'config_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.Ratio)
  })
_sym_db.RegisterMessage(Ratio)

AutoServoOffConfig = _reflection.GeneratedProtocolMessageType('AutoServoOffConfig', (_message.Message,), {
  'DESCRIPTOR' : _AUTOSERVOOFFCONFIG,
  '__module__' : 'config_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.AutoServoOffConfig)
  })
_sym_db.RegisterMessage(AutoServoOffConfig)

CollTuningConfig = _reflection.GeneratedProtocolMessageType('CollTuningConfig', (_message.Message,), {
  'DESCRIPTOR' : _COLLTUNINGCONFIG,
  '__module__' : 'config_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.CollTuningConfig)
  })
_sym_db.RegisterMessage(CollTuningConfig)

JointGainSet = _reflection.GeneratedProtocolMessageType('JointGainSet', (_message.Message,), {
  'DESCRIPTOR' : _JOINTGAINSET,
  '__module__' : 'config_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.JointGainSet)
  })
_sym_db.RegisterMessage(JointGainSet)

TaskGainSet = _reflection.GeneratedProtocolMessageType('TaskGainSet', (_message.Message,), {
  'DESCRIPTOR' : _TASKGAINSET,
  '__module__' : 'config_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.TaskGainSet)
  })
_sym_db.RegisterMessage(TaskGainSet)

ImpedanceGainSet = _reflection.GeneratedProtocolMessageType('ImpedanceGainSet', (_message.Message,), {
  'DESCRIPTOR' : _IMPEDANCEGAINSET,
  '__module__' : 'config_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ImpedanceGainSet)
  })
_sym_db.RegisterMessage(ImpedanceGainSet)

ForceGainSet = _reflection.GeneratedProtocolMessageType('ForceGainSet', (_message.Message,), {
  'DESCRIPTOR' : _FORCEGAINSET,
  '__module__' : 'config_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ForceGainSet)
  })
_sym_db.RegisterMessage(ForceGainSet)

TestGainSet = _reflection.GeneratedProtocolMessageType('TestGainSet', (_message.Message,), {
  'DESCRIPTOR' : _TESTGAINSET,
  '__module__' : 'config_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.TestGainSet)
  })
_sym_db.RegisterMessage(TestGainSet)

CustomGainSet = _reflection.GeneratedProtocolMessageType('CustomGainSet', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMGAINSET,
  '__module__' : 'config_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.CustomGainSet)
  })
_sym_db.RegisterMessage(CustomGainSet)

NewControllerTestState = _reflection.GeneratedProtocolMessageType('NewControllerTestState', (_message.Message,), {
  'DESCRIPTOR' : _NEWCONTROLLERTESTSTATE,
  '__module__' : 'config_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.NewControllerTestState)
  })
_sym_db.RegisterMessage(NewControllerTestState)

FrictionCompSet = _reflection.GeneratedProtocolMessageType('FrictionCompSet', (_message.Message,), {
  'DESCRIPTOR' : _FRICTIONCOMPSET,
  '__module__' : 'config_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.FrictionCompSet)
  })
_sym_db.RegisterMessage(FrictionCompSet)

MountingAngles = _reflection.GeneratedProtocolMessageType('MountingAngles', (_message.Message,), {
  'DESCRIPTOR' : _MOUNTINGANGLES,
  '__module__' : 'config_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.MountingAngles)
  })
_sym_db.RegisterMessage(MountingAngles)

ToolProperties = _reflection.GeneratedProtocolMessageType('ToolProperties', (_message.Message,), {
  'DESCRIPTOR' : _TOOLPROPERTIES,
  '__module__' : 'config_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ToolProperties)
  })
_sym_db.RegisterMessage(ToolProperties)

CollisionSensLevel = _reflection.GeneratedProtocolMessageType('CollisionSensLevel', (_message.Message,), {
  'DESCRIPTOR' : _COLLISIONSENSLEVEL,
  '__module__' : 'config_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.CollisionSensLevel)
  })
_sym_db.RegisterMessage(CollisionSensLevel)

CollisionThresholds = _reflection.GeneratedProtocolMessageType('CollisionThresholds', (_message.Message,), {
  'DESCRIPTOR' : _COLLISIONTHRESHOLDS,
  '__module__' : 'config_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.CollisionThresholds)
  })
_sym_db.RegisterMessage(CollisionThresholds)

CollisionPolicy = _reflection.GeneratedProtocolMessageType('CollisionPolicy', (_message.Message,), {
  'DESCRIPTOR' : _COLLISIONPOLICY,
  '__module__' : 'config_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.CollisionPolicy)
  })
_sym_db.RegisterMessage(CollisionPolicy)

SafetyLimits = _reflection.GeneratedProtocolMessageType('SafetyLimits', (_message.Message,), {
  'DESCRIPTOR' : _SAFETYLIMITS,
  '__module__' : 'config_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.SafetyLimits)
  })
_sym_db.RegisterMessage(SafetyLimits)

SafetyStopConfig = _reflection.GeneratedProtocolMessageType('SafetyStopConfig', (_message.Message,), {
  'DESCRIPTOR' : _SAFETYSTOPCONFIG,
  '__module__' : 'config_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.SafetyStopConfig)
  })
_sym_db.RegisterMessage(SafetyStopConfig)

DIConfig = _reflection.GeneratedProtocolMessageType('DIConfig', (_message.Message,), {
  'DESCRIPTOR' : _DICONFIG,
  '__module__' : 'config_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.DIConfig)
  })
_sym_db.RegisterMessage(DIConfig)

DIConfigList = _reflection.GeneratedProtocolMessageType('DIConfigList', (_message.Message,), {
  'DESCRIPTOR' : _DICONFIGLIST,
  '__module__' : 'config_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.DIConfigList)
  })
_sym_db.RegisterMessage(DIConfigList)

DOConfig = _reflection.GeneratedProtocolMessageType('DOConfig', (_message.Message,), {
  'DESCRIPTOR' : _DOCONFIG,
  '__module__' : 'config_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.DOConfig)
  })
_sym_db.RegisterMessage(DOConfig)

DOConfigList = _reflection.GeneratedProtocolMessageType('DOConfigList', (_message.Message,), {
  'DESCRIPTOR' : _DOCONFIGLIST,
  '__module__' : 'config_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.DOConfigList)
  })
_sym_db.RegisterMessage(DOConfigList)


# @@protoc_insertion_point(module_scope)
